OC.L10N.register(
    "contacts",
    {
    "Details" : "التفاصيل",
    "All contacts" : "كل جهات الإتصال",
    "Contacts" : "جهات الاتصال",
    "Copy to full name" : "انسخ إلى الإسم الكامل",
    "Download" : "تحميل",
    "Groups" : "مجموعات",
    "Group name" : "إسم الفريق",
    "Rename" : "تعديل الإسم",
    "Enabled" : "مفعلة",
    "Disabled" : "معطّل",
    "Delete" : "حذف",
    "Copy link" : "نسخ الرابط",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "can edit" : "يمكن التعديل",
    "First name" : "الإسم",
    "Last name" : "اللقب",
    "Display name" : "الاسم المعروض",
    "Last modified" : "آخر تعديل",
    "Upload a new picture" : "تحميل صورة جديدة",
    "Choose from Files" : "اختر من الملفات",
    "Download picture" : "تنزيل الصورة",
    "Delete picture" : "حذف الصورة",
    "Invalid image" : "الصورة غير صالحة",
    "Image is too big (max 1MB)." : "حجم الصورة كبير جداً (الحجم الأقصى 1MB)",
    "Error while processing the picture." : "حدث خطأ أثناء معالجة الصورة.",
    "Avatar already up to date" : "الصورة الرمزية محدثة بالفعل",
    "Avatar download failed" : "فشل تحميل الصورة الرمزية",
    "No contact selected" : "لم يتم تحديد جهة اتصال",
    "Select a contact on the list to begin" : "حدد جهة اتصال في القائمة للبدء",
    "Name" : "الاسم",
    "Company" : "الشركة",
    "Title" : "العنوان",
    "Cancel" : "إلغاء",
    "Address book" : "دفتر العناوين",
    "New contact" : "جهة إتصال جديدة",
    "No results" : "دون أية نتيجة",
    "Select option" : "حدد الخيار",
    "Close" : "إغلاق",
    "Import" : "استيراد",
    "Not grouped" : "غير مصنف",
    "Email" : "البريد الإلكترونى",
    "Nickname" : "كنية.\nلقب.",
    "Detailed name" : "الإسم بالتفصيل",
    "Additional names" : "الأسماء الإضافية",
    "Prefix" : "بادئة",
    "Suffix" : "لاحقة",
    "Notes" : "الملاحظات",
    "Website" : "موقع إلكتروني",
    "Location" : "المكان",
    "Federated Cloud ID" : "معرّف السحابة الخارجية",
    "Home" : "المنزل",
    "Work" : "العمل",
    "Other" : "آخر",
    "Address" : "العنوان",
    "Post office box" : "صندوق البريد",
    "City" : "المدينة",
    "State or province" : "الولاية أو المنطقة.",
    "Postal code" : "الرمز البريدي.",
    "Country" : "البلد",
    "Birthday" : "عيد ميلاد",
    "Anniversary" : "ذكرى سنوية",
    "Date of death" : "تاريخ الوفاة",
    "Instant messaging" : "المراسلة الفورية",
    "Phone" : "الهاتف",
    "Mobile" : "الهاتف المحمول",
    "Fax" : "الفاكس",
    "Fax home" : "فاكس المنزل",
    "Fax work" : "فاكس العمل",
    "Pager" : "النداء",
    "Voice" : "صوت",
    "Social network" : "شبكة اجتماعية",
    "Relative" : "مرتبط",
    "None" : "لا شيء",
    "Unknown" : "مجهول"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
